import requests
from googlesearch import search
from requests.exceptions import ConnectionError, HTTPError
from bs4 import BeautifulSoup
from .error_handling import SearchNotWork, NoResultFound

class Mangaography:
  def __init__(self, title: str):
    try:
      manga_id = search(f'site:myanimelist.net {title} inurl:/manga/ manga info', num_results=0)
    except HTTPError or ConnectionError:
      raise SearchNotWork('Search Library not work/connection not found')
    if not manga_id:
        raise NoResultFound(f'{manga_id} is Not found')
    try:
      manga_id = ''.join(manga_id).split('/')[4]
    except:
      raise NoResultFound('No Result Found')
    self.manga_id = manga_id or None
    base_url = f'https://api.jikan.moe/v3/manga/{self.manga_id}'
    url = requests.get(base_url)
    result = url.json()
    self.result = result
#manga name
    name = result['title']
    self.name = name or None
#manga en name
    name_en = result['title_english']
    self.name_en = name_en or None
#manga jp name
    name_jp = result['title_japanese']
    self.name_jp = name_jp
#anime url
    manga_url = result['url']
    self.manga_url = manga_url or None

#image anime url
    image_url = result['image_url']
    self.image_url = image_url or None

#type anime, example = TV
    type = result['type']
    self.type = type or None

#score rating anime
    score = result['score']
    self.score = score or None

#aired
    aired = result['published']['string']
    self.aired = aired or None

#ranking
    ranking = result['rank']
    self.ranking = ranking or None

#popularity
    popularity = result['popularity']
    self.popularity = popularity or None

#synopsis
    synopsis = result['synopsis']
    self.synopsis = synopsis or None
#publishing
    is_publishing = result['publishing']
    self.is_publishing = is_publishing or None
#volumes
    volume = result['volumes']
    self.volume = volume
#chapter
    chapter = result['chapters']
    self.chapter = chapter
#member
    member = result['members']
    self.member = member
#favorites
    favorite = result['favorites']
    self.favorite = favorite or None
#status
    status = result['status']
    self.status = status

#author
  @property
  def author(self) -> list:
      author = []
      for nama in self.result['authors']:
          author.append(nama['name'])
      author = ', '.join(author)
      return author or None
#genre
  @property
  def genres(self) -> list:
      genres = []
      for nama in self.result['genres']:
          genres.append(nama['name'])
      genres = ', '.join(genres)
      return genres or None
#related
  @property
  def related(self) -> list:
      related = []
      try:
        for nama in self.result['related']['Adaptation']:
          related.append(nama['name'])
      except:
        for nama in self.result['related']['Alternative version']:
          related.append(nama['name'])
      related = ', '.join(related)
      return related or None
#serializations
  @property
  def serialization(self) -> list:
      serialization = []
      for nama in self.result['serializations']:
          serialization.append(nama['name'])
      serialization = ', '.join(serialization)
      return serialization or None
  
  
  
  


import requests
from bs4 import BeautifulSoup
from datetime import date



class Seasonal:
    year = date.today()
    year = str(year).split('-')[0]

    doy = date.today().timetuple().tm_yday

        # "day of year" ranges for the northern hemisphere
    spring = range(80, 172)
    summer = range(172, 264)
    fall = range(264, 355)
        # winter = everything else

    if doy in spring:
            season = 'spring'
    elif doy in summer:
            season = 'summer'
    elif doy in fall:
            season = 'fall'
    else:
        season = 'winter'
        
    def __init__(self, limit='3', years=year, seasons=season): 

        url = requests.get(f'https://myanimelist.net/anime/season/{years}/{seasons}')
        soup = BeautifulSoup(url.content, 'html.parser')

        if int(limit) >= 9:
            raise KeyError('too many requests, limit max is 9')
        limit = int(limit)
        nama = soup.find_all('a', {"class": "link-title"})[:limit]
        name = []
        for namaa in nama:
            name.append(namaa.text)
        name = ', '.join(name)
        self.name = name or None




from requests import get
from random import choice

class Animages:
        url1 = 'https://nekos.best/api/v1/'
        url2 = 'https://api.waifu.pics/sfw/'
        url3 = 'https://purrbot.site/api/img/sfw/'
        @classmethod
        def pict(anu, url: str) -> str:
            re = get(url).json()
            try:
                return re['url']
            except:
                return re['link']
        @classmethod
        def neko(anu):
            """Neko random images"""
            nekoo = choice(['neko/img', 'neko/gif'])
            nekoo = choice([anu.url3 + nekoo, 'https://api.waifu.pics/sfw/neko', anu.url1 + 'nekos'])
            return anu.pict(nekoo)
        @classmethod
        def bite(anu):
            """Bite anime random images"""
            bite = choice([anu.url1 + 'bite', anu.url2 + 'bite', anu.url3 + 'bite/gif'])
            return anu.pict(bite)
        @classmethod
        def blush(anu):
            "blush random image"
            blush = choice([anu.url3 + 'blush/gif', anu.url1 + 'blush', anu.url2 + 'blush'])
            return anu.pict(blush)
        @classmethod
        def waifu(anu):
            return anu.pict(anu.url2 + 'waifu')
        @classmethod
        def baka(anu):
            return anu.pict(anu.url1 + 'baka')
        @classmethod
        def bored(anu):
            return anu.pict(anu.url1 + 'bored' )
        @classmethod
        def cry(anu):
            cry = choice([anu.url3 + 'cry/gif', anu.url2 + 'cry', anu.url1 + 'cry'])
            return anu.pict(cry)
        @classmethod
        def cuddle(anu):
            cuddle = choice([anu.url1 + 'cuddle', anu.url2 + 'cuddle', anu.url3 + 'cuddle/gif'])
            return anu.pict(cuddle)
        @classmethod
        def dance(anu):
            dance = choice([anu.url1 + 'dance', anu.url2 + 'dance', anu.url3 + 'dance/gif'])
            return anu.pict(dance)
        @classmethod
        def eevee(anu):
            eevee = choice([anu.url3 + 'eevee/gif', anu.url3 + 'eevee/img'])
            return anu.pict(eevee)
        @classmethod
        def feed(anu):
            feed = choice([anu.url1 + 'feed', anu.url3 + 'feed/gif'])
            return anu.pict(feed)
        @classmethod
        def fluff(anu):
            return anu.pict(anu.url3 + 'fluff/gif')
        @classmethod
        def holo(anu):
            return anu.pict(anu.url3 + 'holo/img')
        @classmethod
        def hug(anu):
            hug = choice([anu.url1 + 'hug', anu.url2 + 'hug', anu.url3 + 'hug/gif'])
            return anu.pict(hug)
        @classmethod
        def kiss(anu):
            kiss = choice([anu.url1 + 'kiss', anu.url2 + 'kiss', anu.url3 + 'kiss/gif'])
            return anu.pict(kiss)
        @classmethod
        def kitsune(anu):
            return anu.pict(anu.url3 + 'kitsune/img')
        @classmethod
        def lick(anu):
            lick = choice([anu.url1 + 'lick', anu.url2 + 'lick', anu.url3 + 'lick/gif'])
            return anu.pict(lick)
        @classmethod
        def okami(anu):
            return anu.pict(anu.url3 + 'okami/img')
        @classmethod
        def pat(anu):
            pat = choice([anu.url1 + 'pat', anu.url2 + 'pat', anu.url3 + 'pat/gif'])
            return anu.pict(pat)
        @classmethod
        def poke(anu):
            poke = choice([anu.url1 + 'poka', anu.url2 + 'poka', anu.url3 + 'poke/gif'])
            return anu.pict(poke)
        @classmethod
        def megumin(anu):
            return anu.pict(anu.url2 + 'megumin')
        @classmethod
        def shinobu(anu):
            return anu.pict(anu.url2 + 'shinobu')
        @classmethod
        def senko(anu):
            return anu.pict(anu.url3 + 'senko/img')
        @classmethod
        def slap(anu):
            slap = choice([anu.url1 + 'slap', anu.url2 + 'slap', anu.url3 + 'slap/gif'])
            return anu.pict(slap)
        @classmethod
        def smile(anu):
            smile = choice([anu.url1 + 'smile', anu.url2 + 'smile', anu.url3 + 'smile/gif'])
            return anu.pict(smile)
        @classmethod
        def tail(anu):
            return anu.pict(anu.url3 + 'tail/gif')
        @classmethod
        def tickle(anu):
            tickle = choice([anu.url1 + 'tickle', anu.url3 + 'tickle/gif'])
            return anu.pict(tickle)
        @classmethod
        def facepalm(anu):
            return anu.pict(anu.url1 + 'facepalm')
        @classmethod
        def happy(anu):
            happy = choice([anu.url1 + 'happy', anu.url2 + 'happy'])
            return anu.pict(happy)
        @classmethod
        def highfive(anu):
            return anu.pict([anu.url1 + 'highfive'])
        @classmethod
        def wink(anu):
            wink = choice([anu.url1 + 'wink', anu.url2 + 'wink'])
            return anu.pict(wink)
        @classmethod
        def awoo(anu):
            return anu.pict(anu.url2 + 'awoo')
        @classmethod
        def bonk(anu):
            return(anu.url2 + 'bonl')
        @classmethod
        def smug(anu):
            return anu.pict(choice([anu.url2 + 'smug'], [anu.url1 + 'smug']))
        @classmethod
        def handhold(anu):
            return anu.pict(anu.url2 + 'handhold')
        @classmethod
        def kill(anu):
            return anu.pict(anu.url2 + 'kill')
        @classmethod
        def cringe(anu):
            return anu.pict(anu.url2 + 'cringe')
        @classmethod
        def wave(anu):
            wave = choice([anu.url1 + 'wave', anu.url2 + 'wave'])
            return anu.pict(wave)
        @classmethod
        def bully(anu):
            return anu.pict(anu.url2 + 'bully')
        @classmethod
        def pout(anu):
            return anu.pict(anu.url1 + 'pout')
        @classmethod
        def shrug(anu):
            return anu.pict(anu.url1 + 'shrug')
        @classmethod
        def sleep(anu):
            return anu.pict(anu.url1 + 'sleep')
        @classmethod
        def stare(anu):
            return anu.pict(anu.url1 + 'stare')
        @classmethod
        def think(anu):
            return anu.pict(anu.url1 + 'think')
        @classmethod
        def thumsup(anu):
            return anu.pict(anu.url1 + 'thumsup')
        @classmethod
        def yeet(anu):
            return anu.pict(anu.url2 + 'yeet')
        @classmethod
        def nom(anu):
            return anu.pict(anu.url2 + 'nom')
        @classmethod
        def glomp(anu):
            return anu.pict(anu.url2+ 'glomp')
        @classmethod
        def kick(anu):
            return anu.pict(anu.url2 + 'kick')

        class NSFW:
            url1 = 'https://nekos.life/api/v2/img/'
            url2 = 'https://api.waifu.pics/nsfw/'
            url3 = 'https://purrbot.site/api/img/nsfw/'
            @classmethod
            def nsfw_pict(anu, url: str) -> str:
                re = get(url).json()
                try:
                    return re['url']
                except:
                    return re['link']
            @classmethod
            def anal(anu):
                return anu.nsfw_pict(anu.url3 + 'anal/gif')
            @classmethod
            def blowjob(anu):
                return anu.nsfw_pict(choice([anu.url2 + 'blowjob'], [anu.url3+ 'blowjob/gif']))
            @classmethod
            def cum(anu):
                return anu.nsfw_pict(choice([anu.url3 + 'cum/gif'], [anu.url1 + 'cum']))
            @classmethod
            def waifu(anu):
                return anu.nsfw_pict(anu.url2 + 'waifu')
            @classmethod
            def neko(anu):
                return anu.nsfw_pict(choice([anu.url2 + 'neko'], [anu.url3 + 'neko/gif'], [anu.url3 + 'neko/img'], [anu.url1 + 'nsfw_neko_gif']))
            @classmethod
            def trap(anu):
                return anu.nsfw_pict(anu.url2 + 'trap')
            @classmethod
            def yaoi(anu):
                return anu.nsfw_pict(anu.url3 + 'yaoi/gif')
            @classmethod
            def yuri(anu):
                return anu.nsfw_pict(anu.url3 + 'yuri/gif')
            @classmethod
            def random(anu):
                return anu.nsfw_pict(anu.url3 + 'fuck/gif')
            @classmethod
            def solo(anu):
                return anu.nsfw_pict(anu.url3 + 'solo/gif')
            @classmethod
            def pussylick(anu):
                return anu.nsfw_pict(anu.url3 + 'pussylick/gif')
            @classmethod
            def solog(anu):
                return anu.nsfw_pict(anu.url1 + 'solog')
            @classmethod
            def smallboobs(anu):
                return anu.nsfw_pict(anu.url1 + 'smallbooobs')
            @classmethod
            def lewdkemo(anu):
                return anu.nsfw_pict(anu.url1 + 'lewdkemo')
            @classmethod
            def woof(anu):
                return anu.nsfw_pict(anu.url1 + 'woof')
            @classmethod
            def gasm(anu):
                return anu.nsfw_pict(anu.url1 + 'gasm')
            @classmethod
            def hentai(anu):
                return anu.nsfw_pict(anu.url1 + 'hentai')
            @classmethod
            def ero(anu):
                return anu.nsfw_pict(anu.url1 + 'ero')
            @classmethod
            def hololewd(anu):
                return anu.nsfw_pict(anu.url1 + 'hololewd')
            @classmethod
            def random_gif(anu):
                return anu.nsfw_pict(anu.url1 + 'Random_hentai_gif')
            @classmethod
            def eroyuri(anu):
                return anu.nsfw_pict(anu.url1 + 'eroyuri')


import requests
from .error_handling import NoResultFound
from bs4 import BeautifulSoup
from googlesearch import search

class Lyricspedia:
    def __init__(self, title: str):
        anu = search('site:animesonglyrics.com {}'.format(title), num_results=0)
        abu = ''.join(anu)

        url = requests.get(abu)
        if not url:
            raise NoResultFound(f'{url} Not Found')
        
        soup = BeautifulSoup(url.content, 'html.parser')
        for a in soup.findAll("br"):
            a.replace_with("\n")
        try:
            lyrics_romaji = soup.find('div', {'id': 'tab1'}).text
        except AttributeError:
            raise AttributeError('Can\' find a anime song')
        lyrics_romaji0 = lyrics_romaji.split('[')[0]
        lyrics_romaji1 = lyrics_romaji.split('[')[1]
        lyrics_romaji = '  {} [{}'.format(lyrics_romaji0, lyrics_romaji1)
        lyrics_romaji = lyrics_romaji.replace('                                                            ', '')
        self.lyrics_romaji = lyrics_romaji or None
        try:
            lyrics_en = soup.find('div', {'id': 'tab2'}).text
        except AttributeError:
            raise AttributeError('Can\' find a anime song')
        lyrics_en0 = lyrics_en.split('[')[0]
        lyrics_en1 = lyrics_en.split('[')[1]
        lyrics_en = ' {} [{}'.format(lyrics_en0, lyrics_en1)
        self.lyrics_en = lyrics_en or None
        name = soup.find('div', {'id': 'wrapper'})
        name = name.h1.text
        name = name.replace('                ','')
        self.name = name


import requests
from googlesearch import search
from .error_handling import NoResultFound, SearchNotWork
from requests.exceptions import HTTPError, ConnectionError

class Animegraphy:
  def __init__(self, title: str):
    
    try:
      mal_id = search('site:myanimelist.net {} anime info inurl:anime/'.format(title), num_results=0)
    except HTTPError or ConnectionError:
      raise SearchNotWork('Too many requests or connection error')
    if not mal_id:
        raise NoResultFound(f'{mal_id} is Not found')
    try:
        mal_id = ''.join(mal_id).split('/')[4]
    except:
        raise KeyError('Not found')
    self.mal_id = mal_id
    url = f'https://api.jikan.moe/v3/anime/{self.mal_id}/'
    r = requests.get(url)
    resu = r.json()
    self.resu = resu or None
    #Anime Title
    title = resu['title']
    self.title = title or None

#anime url
    anime_url = resu['url']
    self.anime_url = anime_url or None

#image anime url
    image_url = resu['image_url']
    self.image_url = image_url or None

#rated anime, example = PG - 13
    rated = resu['rating']
    self.rated = rated or None

#type anime, example = TV
    type_nime = resu['type']
    self.type = type_nime or None

#score rating anime
    score = resu['score']
    self.score = score or None

#episode anime
    eps = resu['episodes']
    self.eps = eps or None


#opening song
    op_song = resu['opening_themes']
    op_song = '"'.join(op_song)
    self.op_song = op_song or None

#ending song
    ed_song = resu['ending_themes']
    ed_song = '"'.join(ed_song)
    self.ed_song = ed_song or None

#aired
    aired = resu['aired']['string']
    self.aired = aired or None

#ranking
    ranknim = resu['rank']
    self.rank = ranknim or None

#popularity
    popularity = resu['popularity']
    self.popularity = popularity or None

#synopsis
    synopsis = resu['synopsis']
    self.synopsis = synopsis or None

#trailer url(EMBED)
    trailer_url = resu['trailer_url']
    trailer_url = trailer_url.split('/')[4].split('?')[0]
    trailer_url = f'https://youtube.com/watch?v={trailer_url}'
    self.trailer_url = trailer_url or None
#status anime
    status = resu['status']
    self.status = status or None
#premiered
    premiered = resu['premiered']
    self.premiered = premiered or None
#broadcast
    broadcast = resu['broadcast']
    self.broadcast = broadcast or None
#adaptation anime type
    try:
        adaptation_type = resu['related']['Adaptation'][0]['type']
    except:
        adaptation_type = "This Anime Doesn't Have A Manga/Anime Adaptation"
    self.adaptation_type = adaptation_type or None
#adaptation anime name
    try:
        adaptation_name = resu['related']['Adaptation'][0]['name']
    except:
        adaptation_name = "This Anime Doesn't Have A Manga/Anime Adaptation"
    self.adaptation_name = adaptation_name or None
#sequel name
    try:
        sequel_name = resu['related']['Sequel'][0]['name']
    except:
        sequel_name = "This Anime Doesn't Have A Anime Sequel"
    self.sequel = sequel_name or None
#sequel url
    try:
        sequel_url = resu['related']['Sequel'][0]['url']
    except:
        sequel_url = "This Anime Doesn't Have A Anime Sequel"
    self.sequel_url = sequel_url or None
#adaptation
    adaptation = f' {adaptation_type}, {adaptation_name}'
    self.adaptation = adaptation or None
#favorite
    favorite = resu['favorites']
    self.favorite = favorite or None
#duration
    duration = resu['duration']
    self.duration = duration or None
#source
    source = resu['source']
    self.source = source or None
#background
    background = resu['background']
    self.background = background or None
  @property
  def studio(self):
      studio = []
      for nama in self.resu['studios']:
          studio.append(nama['name'])
      studio = ', '.join(studio)
      return studio or None
  @property
  def genre(self) -> list:
      genre = []
      for nama in self.resu['genres']:
          genre.append(nama['name'])
      genre = ', '.join(genre)
      return genre or None
  @property
  def producers(self):
      producers = []
      for nama in self.resu['producers']:
          producers.append(nama['name'])
      producers = ', '.join(producers)
      return producers or None
  @property
  def recommend(self):
      recommend = []
      url = f'https://api.jikan.moe/v3/anime/{self.mal_id}/recommendations'
      su = requests.get(url)
      sult = su.json()
      self.sult = sult
      for nama in self.sult['recommendations']:
          recommend.append(nama['title'])
      recommend = recommend[:5]
      recommend = '; '.join(recommend)
      return recommend or None
  def nsfw_scan(self) -> bool:
      return any(a in self.rated for a in ['R', '17'])


from .animpedia import *
from .lyricsnim import *
from .quotepedia import *
from .char import *
from .manga import *
from .genshin import *
from .season import *
from .pict import *
from .secret import *

__version__ = '1.6.5'




class Genshinchar:

  help = '''
  endpoints:
  character('name')
  character('id')
  character('slug')
  character('description')
  character('weapon')
  character('obtain')
  character('gender')
  character('rarity')
  character('birthday')
  character('vision')
  '''
  
  def __init__(self, query: str):
    char = [
    {"id":6,"name":"Diluc","slug":"diluc","description":"The tycoon of a winery empire in Mondstadt, unmatched in every possible way.","gender":"male","birthday":"April 30th","rarity":5,"vision":"pyro","weapon":"claymore","obtain":"Wish"},
{"id":8,"name":"Jean","slug":"jean","description":"The righteous and rigorous Dandelion Knight, and Acting Grand Master of the Knights of Favonius in Mondstadt.","gender":"female","birthday":"March 14th","rarity":5,"vision":"anemo","weapon":"sword","obtain":"Wish"},
{"id":10,"name":"Keqing","slug":"keqing","description":"The Yuheng of the Liyue Qixing. Has much to say about Rex Lapis unilateral approach to policymaking in Liyue - but in truth, gods admire skeptics such as her quite a lot.","gender":"female","birthday":"Nov 20th","rarity":5,"vision":"electro","weapon":"sword","obtain":"Wish"},
{"id":11,"name":"Klee","slug":"klee","description":"An explosives expert and a regular at the Knights of Favonius\r\n confinement room. Also known as Fleeing Sunlight.","gender":"female","birthday":"Jul 27th","rarity":5,"vision":"pyro","weapon":"catalyst","obtain":"Wish"},
{"id":13,"name":"Mona","slug":"mona","description":"A mysterious young astrologer who proclaims herself to be Astrologist Mona Megistus,  and who possesses abilities to match the title.","gender":"female","birthday":"Aug 31st","rarity":5,"vision":"hydro","weapon":"catalyst","obtain":"Wish"},
{"id":16,"name":"Qiqi","slug":"qiqi","description":"An apprentice and herb-picker Bubu Pharmacy. An undead with a bone-white complexion, she seldom has much in the way of words or emotion.","gender":"female","birthday":"March 3rd","rarity":5,"vision":"cryo","weapon":"sword","obtain":"Wish"},
{"id":21,"name":"Venti","slug":"venti","description":"One of the many bards of Mondstadt, who freely wanders the citys streets and alleys.","gender":"male","birthday":"Jun 16th","rarity":5,"vision":"anemo","weapon":"bow","obtain":"Wish"},
{"id":23,"name":"Xiao","slug":"xiao","description":"A yaksha adeptus that defends Liyue. Also heralded as the Conqueror of Demons or Vigilant Yaksha.","gender":"male","birthday":"April 17th","rarity":5,"vision":"anemo","weapon":"polearm","obtain":"Wish"},
{"id":26,"name":"Tartaglia","slug":"tartaglia","description":"Cunning Snezhnayan whose unpredictable personality keeps people guessing his every move.","gender":"male","birthday":"July 20th","rarity":5,"vision":"hydro","weapon":"bow","obtain":"Unknown"},
{"id":28,"name":"Zhongli","slug":"zhongli","description":"A mysterious guest invited by the Wangsheng Funeral Parlor. Extremely knowledgeable in all things.","gender":"male","birthday":"Dec 31st","rarity":5,"vision":"geo","weapon":"polearm","obtain":"Unknown"},
{"id":1,"name":"Amber","slug":"amber","description":"Always energetic and full of life, Ambers the best - albeit only - Outrider of the Knights of Favonius.","gender":"female","birthday":"Aug 24th","rarity":4,"vision":"pyro","weapon":"bow","obtain":"Quest"},
{"id":2,"name":"Barbara","slug":"barbara","description":"Every denizen of Mondstadt adores Barbara. However, she learned the word idol from a magazine.","gender":"female","birthday":"Jul 5th","rarity":4,"vision":"hydro","weapon":"catalyst","obtain":"Wish"},
{"id":3,"name":"Beidou","slug":"beidou","description":"Beidou is the leader of the Crux an armed fleet based in Liyue Harbor. An armed fleet means exactly what it sounds like: a fleet of ships armed to the teeth.","gender":"female","birthday":"Feb 14th","rarity":4,"vision":"electro","weapon":"claymore","obtain":"Wish"},
{"id":4,"name":"Bennett","slug":"bennett","description":"A righteous and good-natured adventurer from Mondstadt whos unfortunately extremely unlucky.","gender":"male","birthday":"Feb 29th","rarity":4,"vision":"pyro","weapon":"sword","obtain":"Wish"},
{"id":5,"name":"Chongyun","slug":"chongyun","description":"A young exortcist from a family of exorcists. He does everything he can to suppress his pure positive energy.","gender":"male","birthday":"Sep 7th","rarity":4,"vision":"cryo","weapon":"claymore","obtain":"Wish"},
{"id":7,"name":"Fischl","slug":"fischl","description":"A mysterious girl who calls herself Prinzessia der Verurteilung and travels with a night raven named Oz.","gender":"female","birthday":"May 27th","rarity":4,"vision":"electro","weapon":"bow","obtain":"Wish"},
{"id":9,"name":"Kaeya","slug":"kaeya","description":"A thinker in the Knights of Favonius with a somewhat exotic appearance.","gender":"male","birthday":"Nov 30th","rarity":4,"vision":"cryo","weapon":"sword","obtain":"Quest"},
{"id":12,"name":"Lisa","slug":"lisa","description":"The languid but knowledgeable Librarian of the Knights of Favonius who was deemed by Sumeru Academia to be their most distinguised graduate in the past two centuries.","gender":"female","birthday":"Jun 9th","rarity":4,"vision":"electro","weapon":"catalyst","obtain":"Quest"},
{"id":14,"name":"Ningguang","slug":"ningguang","description":"The Tianquan of Liyue Qixing. Her wealth is unsurpassed in all of Teyvat.","gender":"female","birthday":"Aug 26th","rarity":4,"vision":"geo","weapon":"catalyst","obtain":"Wish"},
{"id":15,"name":"Noelle","slug":"noelle","description":"A maid in the service of the Knights of Favonius that dreams of joining their ranks someday.","gender":"female","birthday":"March 21st","rarity":4,"vision":"geo","weapon":"claymore","obtain":"Wish"},
{"id":17,"name":"Razor","slug":"razor","description":"A boy who lives among the wolves in Wolvendom of Mondstadt, away from human civilization. As agile as lightning.","gender":"male","birthday":"Sep 9th","rarity":4,"vision":"electro","weapon":"claymore","obtain":"Wish"},
{"id":18,"name":"Sucrose","slug":"sucrose","description":"An alchemist filled with curiosity about all things. She researches bio-alchemy.","gender":"male","birthday":"May 11th","rarity":4,"vision":"anemo","weapon":"catalyst","obtain":"Wish"},
{"id":22,"name":"Xiangling","slug":"xiangling","description":"A renowned chef from Liyue. Shes extremely passionate about cooking and excels at making her signature hot and spicy dishes.","gender":"female","birthday":"Nov 2nd","rarity":4,"vision":"pyro","weapon":"polearm","obtain":"Wish"},
{"id":24,"name":"Xingqiu","slug":"xingqiu","description":"A young man carrying a longsword who is frequently seen at book booths. He has a chivalrous heart and yearns for justice and fairness for all.","gender":"male","birthday":"Oct 9th","rarity":4,"vision":"hydro","weapon":"sword","obtain":"Wish"},
{"id":25,"name":"Diona","slug":"diona","description":"A young lady who has inherited trace amounts of non-human blood. She is the incredible popular bartender of the Cats Tail tavern.","gender":"female","birthday":"Jan 18th","rarity":4,"vision":"cryo","weapon":"bow","obtain":"Unknown"},
{"id":27,"name":"Xinyan","slug":"xinyan","description":"Liyues sole rock 'n' roll musician. She rebels against ossified prejudices using her music and passionate singing.","gender":"female","birthday":"Nov 4th","rarity":4,"vision":"pyro","weapon":"claymore","obtain":"Unknown"},
{"id":28, "name":"Kamisato Ayaka", "slug":"ayaka", "description":"Daughter of the Yashiro Commission's Kamisato Clan. Dignified and elegant, as well as wise and strong.", "gender": "female", "birthday":"Sep 28th", "rarity":5, "vision":"Cryo", "weapon":"sword", "obtain":"wish"},
{"id":29, "name":"Raiden Shogun", "slug":"baal", "description":"Her Excellency, the Almighty Narukami Ogosho, who promised the people of Inazuma an unchanging Eternity.", "gender":"female", "birthday":"Jun 2th", "rarity":5, "vision":"archon electro", "weapon":"lightning", "obtain":"wish"}
]
    try:
      diluc = char[0][query]
      self.diluc = diluc or None
      jean = char[1][query]
      self.jean = jean or None
      keqing = char[2][query]
      self.keqing = keqing or None
      klee = char[3][query]
      self.klee = klee
      mona = char[4][query]
      self.mona = mona or None
      qiqi = char[5][query]
      self.qiqi = qiqi or None
      venti = char[6][query]
      self.venti = venti or None
      xiao = char[7][query]
      self.xiao = xiao or None
      tartanglia = char[8][query]
      self.tartanglia = tartanglia or None
      zhongli = char[9][query]
      self.zhongli = zhongli or None
      amber = char[10][query]
      self.amber = amber or None
      barbara = char[11][query]
      self.barbara = barbara or None
      beidou = char[12][query]
      self.beidou = beidou or None
      bennnett = char[13][query]
      self.bennett = bennnett or None
      chongyun = char[14][query]
      self.chongyun = chongyun or None
      fischl = char[15][query]
      self.fischl = fischl or None
      kaeya = char[16][query]
      self.kaeya = kaeya or None
      lisa = char[17][query]
      self.lisa = lisa or None
      ningguang = char[18][query]
      self.ningguang = ningguang or None
      noelle = char[19][query]
      self.noelle = noelle or None
      razor = char[20][query]
      self.razor = razor or None
      sucrose = char[21][query]
      self.sucrose = sucrose or None
      xiangling = char[22][query]
      self.xianling = xiangling or None
      xiangqiu = char[23][query]
      self.xiangqiu = xiangqiu or None
      diona = char[24][query]
      self.diona = diona or None
      xinyan = char[25][query]
      self.xinyan = xinyan or None
      ayaka = char[26][query]
      self.ayaka = ayaka or None
      baal = char[27][query]
      self.baal = baal or None
    except KeyError:
      raise KeyError('''Not in endpoints, for help in help, example: id = character('id'), print(id.help), or print(character.help''')




import requests
from googlesearch import search
from bs4 import BeautifulSoup
from .error_handling import SearchNotWork, NoResultFound

class Charapedia:
  def __init__(self, char: str):
    
    try:
      mal_char_id = search('site:myanimelist.net {} character info inurl:/character/'.format(char), num_results=0)
    except SearchNotWork:
      raise SearchNotWork('Search Library Not Work')
    if not mal_char_id:
      raise NoResultFound('No Result Found')
    try:
      mal_char_id = ''.join(mal_char_id).split('/')[4]
    except:
      raise NoResultFound('Character Not Found')
    self.mal_char_id = mal_char_id
    base_api = 'https://api.jikan.moe/v3/character/{}/'.format(self.mal_char_id)
    r = requests.get(base_api)
    result = r.json()
    self.result = result
    
    #Caharcter Name
    try:
      name = result['name']
      name = f'{name} ({result["name_kanji"]})'
    except KeyError:
      raise NoResultFound(f'{char} is not Anime characters or u typo')
    self.name = name or None
#url name
    url = result['url']
    self.url = url
#image url
    image_url = result['image_url']
    self.image_url = image_url
#about
    about = result['about']
    if 'No biography written.' in about:
      self.age = about
    about = ''.join(about)
    self.about = about
    self.anu = self.about.split('\n')
#age
    try:
      age = self.anu[0].split('Age: ')[1]
    except:
      age = 'Age biography not written.'
    self.age = age
#birthday
    try:
      try:
        birthday = self.anu[1].split('Birthday: ')[1]
      except:
        birthday = self.anu[0].split('Birthday: ')[1]
    except:
      birthday = 'Birthday biography not written'
    self.birthday = birthday
#height
    
    try:
      try:
        height = self.anu[1].split('Height: ')[1]
      except:
        try:
          height = self.anu[2].split('Height: ')[1]
        except:
          height = self.anu[3].split('Height:')[1]
    except:
      height = 'Height biography not written'
    self.height = height
#weight
    try:
      try:
        weight = self.anu[1].split('Weight: ')[1]
      except:
        try:
          weight = self.anu[2].split('Weight: ')[1]
        except:
          weight = self.anu[3].split('Weight:')[1]
    except:
      weight = 'weight biography not written'
    self.weight = weight
#nickname
    nickname = result['nicknames']
    nickname = ', '.join(nickname)
    if ',' not in nickname:
      nickname = 'None'
    self.nickname = nickname
#anime reference
  @property
  def anime(self) -> list:
    anime = []
    for nama in self.result['animeography']:
      anime.append(nama['name'])
    anime = ', '.join(anime)
    return anime or None
#manga reference
  @property
  def manga(self) -> list:
    manga = []
    for nama in self.result['mangaography']:
      manga.append(nama['name'])
    manga = ', '.join(manga)
    return manga or None



from random import choice
import os
import requests



#uhh
class Quotenime:
    base_url = ['https://animechan.vercel.app/api/random', 'https://some-random-api.ml/animu/quote']
    base_url = choice(base_url)
    if 'some-random' in base_url:
      r = requests.get(base_url)
      result = r.json()
      quote = result['sentence']
      char = result['characther']
      anime = result['anime']
    else:
      re = requests.get(base_url)
      resu = re.json()
      quote = resu['quote']
      char = resu['character']
      anime = resu['anime']

    quote = quote or None
    char = char or None
    anime = anime or None



from setuptools import find_packages, setup


with open('README.md', 'r') as fh:
    long_description = fh.read()
with open('requirements.txt', 'r') as fh:
    module = fh.read()
setup(
    name="Anipick",
    author="Kenzawa/Babwa",
    author_email="babwaxgura@gmail.com",
    version='1.6.5',
    description="Anime module for search Anime, Manga, Quote info",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    include_package_data=True,
    classifiers=[
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3",
    "Topic :: Software Development :: Libraries",
],
    entry_points = {
        'console_scripts': ['anipick = anipick.isi:main',]
    },
    python_requires='>=3.6',               
    py_modules=["anipick"],             
    url="https://github.com/pengode-handal/anipick",
    packages=find_packages(),
    install_requires=module,
    keywords=['anipick', 'Anipick', 'anime', 'python3', 'python', 'Anime', 'images'],
    zip_safe=False
)


from rich.console import Console
import anipick
import argparse
import tabulate


def main():
    parse = argparse.ArgumentParser()
    parse.add_argument('-a', '--anime', metavar='title', help='get info of anime', nargs='+')
    parse.add_argument('-m', '--manga', metavar='title', help='get manga info', nargs='+')
    parse.add_argument('-ly', '--lyrics', metavar='keyword', help='get lyrics of the anime song', nargs='+')
    parse.add_argument('-s', '--song', help='usage: False/True')
    parse.add_argument('-tf', '--tablefmt', help='setting the table fmt')
    parse.add_argument('-q', '--quote',action='store_true' ,help='random quotes nime', required=False)
    parse.add_argument('-c', '--char', help='get character info', nargs='+')
    parse.add_argument('--author', action='version', version='Kenzawa/Babwa')
    parse.add_argument('-v', '--version', action='version', version='1.6.5')
    parse.add_argument('-nc', '--ncode', metavar='keyword', nargs='+', help='get ncode')
    parse.add_argument('-sn', '--seasonal', action='store_true', help='get title anime in specified seasonal')


    args = parse.parse_args()

    if args.anime:
        ' '.join(args.anime)
        title = anipick.Animegraphy(args.anime)
        name = title.title
        genre = title.genre
        eps = title.eps
        aired = title.aired
        studio = title.studio
        id = title.mal_id
        broadcast = title.broadcast
        adaptation = title.adaptation
        duration = title.duration
        nsfw = title.nsfw_scan()
        score = title.score
        rank = title.rank
        sequel = title.sequel
        status = title.status
        rated = title.rated
        try:
            op = title.op_song
            ed = title.ed_song
            op = op.split('#')[0:3]
            op = ', '.join(op)
            ed = ed.split('#')[0:3]
            ed = ', '.join(ed)
        except:
            op = 'Opening Song Not Found'
            ed = 'Ending Song Not Found'
        table = [['Anime', name], ['MAL ID', id], ['Status', status], ['Episode', eps], ['Aired', aired], ['Studio', studio],['Broadcast', broadcast], ['Duration', duration], ['NSFW', nsfw], [
        'Sequel', sequel], ['Score', score], ['RANK', rank], ['Genre', genre],['Adaptation', adaptation], ['Rated', rated]]
        try:
            if 'rue' in args.song:
                table = [['Anime', name], ['MAL ID', id], ['Status', status], ['Episode', eps], ['Aired', aired], ['Studio', studio],['Broadcast', broadcast], ['Duration', duration], ['NSFW', nsfw], [
            'Sequel', sequel], ['Score', score], ['RANK', rank], ['Genre', genre],['Adaptation', adaptation], ['Rated', rated], ['Opening', op], ['Ending', ed]]
            if 'lse' in args.song:
                table = [['Anime', name], ['MAL ID', id], ['Status', status], ['Episode', eps], ['Aired', aired], ['Studio', studio],['Broadcast', broadcast], ['Duration', duration], ['NSFW', nsfw], [
            'Sequel', sequel], ['Score', score], ['RANK', rank], ['Genre', genre],['Adaptation', adaptation], ['Rated', rated]]
        except:
            table = [['Anime', name], ['MAL ID', id], ['Status', status], ['Episode', eps], ['Aired', aired], ['Studio', studio],['Broadcast', broadcast], ['Duration', duration], ['NSFW', nsfw], [
        'Sequel', sequel], ['Score', score], ['RANK', rank], ['Genre', genre],['Adaptation', adaptation], ['Rated', rated]]
        if args.tablefmt:
            print(tabulate.tabulate(table, headers='firstrow', tablefmt=args.tablefmt))
        else:
            print(tabulate.tabulate(table, headers='firstrow'))
    if args.manga:
        ' '.join(args.manga)
        manga = anipick.Mangaography(args.manga)
        title = f'{manga.name} ({manga.name_jp})'
        aired = manga.aired
        genre = manga.genres
        author = manga.author
        status = manga.status
        publish = manga.is_publishing
        serialization = manga.serialization
        chapter = manga.chapter
        volume = manga.volume
        score = manga.score
        id = manga.manga_id
        related = manga.related
        table = [['Manga', title], ['MAL ID', id], ['Score', score], ['Publish', publish], ['Author', author], ['Status', status],
        ['Chapter', chapter], ['Volume', volume], ['Genre', genre], ['Related', related], ['Serialization', serialization], ['Aired', aired]]
        if args.tablefmt:
            print(tabulate.tabulate(table, headers='firstrow', tablefmt=args.tablefmt))
        else:
            print(tabulate.tabulate(table, headers='firstrow'))
    if args.quote:
            quotenime = anipick.Quotenime()
            anime = quotenime.anime
            quote = quotenime.quote
            char = quotenime.char
            table = [['Anime', anime], ['Character', char], ['Quotes', quote]]
            if args.tablefmt:
                print(tabulate.tabulate(table, headers='firstrow', tablefmt=args.tablefmt))
            else:
                print(tabulate.tabulate(table, headers='firstrow'))
    if args.lyrics:
        ' '.join(args.lyrics)
        query = anipick.Lyricspedia(args.lyrics)
        romaji = query.lyrics_romaji
        print(query.name ,romaji, sep='\n')

    if args.char:
        ' '.join(args.char)
        char = anipick.Charapedia(args.char)
        name = char.name
        nickname = char.nickname
        about = f'Height: {char.height}, Weight: {char.weight}, Birthday: {char.birthday}'
        id = char.mal_char_id
        animm = str(char.anime)
        animm = animm.replace(',', ',:').split(':')[0:5]
        animm = ', '.join(animm)
        mangaa = str(char.manga)
        mangaa = mangaa.replace(',', ',:').split(':')[0:5]
        mangaa = ', '.join(mangaa)
        table = [['Name', name], ['NickName', nickname], ['MAL CHAR ID', id], ['About:', about], ['Anime', animm], ['Manga', mangaa]]
        if args.tablefmt:
                print(tabulate.tabulate(table, headers='firstrow', tablefmt=args.tablefmt))
        else:
                print(tabulate.tabulate(table, headers='firstrow'))
    
    if args.ncode:
        ' '.join(args.ncode)
        code = anipick.HGEN('tobat_yuk_bang', query=args.ncode)
        print(code.nuclear)
    
    if args.seasonal:
        resultt = anipick.Seasonal(limit=5)
        table = [['Year', resultt.year], ['Season', resultt.season], ['anime', resultt.name]]
        if args.tablefmt:
                print(tabulate.tabulate(table, tablefmt=args.tablefmt))
        else:
                print(tabulate.tabulate(table))
if __name__ == '__main__':
    main()